/*
 *	MatlabPlot.cpp
 *
 *  This is program illustrates how to call the MATLAB
 *  Engine functions from a C or C++ program to use MATLAB's
 *  plot() function. The data array to be plotted is read from
 *  the C6713 DSK using RTDX.  The program assumes that the data was sent by 
 *  the DSK program SendAnArray.c which sends two arrays of 100 32-bit 
 *  floating point words.
 */

#import "C:\CCStudio_v3.1\cc\bin\rtdxint.dll"

#include <iostream>
#include "engine.h" // in C:\matlab_sv13\extern\include
/*
 * Note:  Add the path to your header files by clicking on Tools -> Options 
 *  -> Projects and Solutions -> VC++ Directories -> Show Directories for: ->
 *  drop down box for Include Files. Click under the list of files. The use the
 *  "..." icon to browse to your include file directory.  Add the Matlab libeng.lib 
 *  and libmx.lib libraries to your project by clicking on Project -> Add Existing Item.

 */

using namespace RTDXINTLib;
using namespace std;

int main()
{
#define BUF_SIZE 100
    IRtdxExpPtr rtdx;          // Holds pointer to IRtdxExp interface
//		long idata;            // Holds integer data read from target application
		float fdata;           // Holds floating point data read from target

	int nn;
	int data_count = 0;

    long status;               // Holds status of RTDX COM API calls
    HRESULT hr;                // Holds status of generic COM API calls

	Engine *ep;
	mxArray *T = NULL;
	mxArray *Ydata = NULL; 

	double time[BUF_SIZE];
	for(nn=0;nn<BUF_SIZE;nn++) time[nn] = nn;

	double data_from_dsk[BUF_SIZE];

/*
	 * Start the MATLAB engine locally by executing the string
	 * "matlab"
	 */
	if (!(ep = engOpen("\0"))) {        /* "\0" is the NULL character */
		cout << "\nCan't start MATLAB engine\n";
		return EXIT_FAILURE;
	}

	/* 
	 * Create a variable for our x-axis data
	 *   mxCreateDoubleMatrix(i,j, mxREAL) allocates space on the heap
	 * for a matrix with i rows and j columns with real elements all
	 * initialized to 0. Make sure to deallocate (destroy) this array
	 * when it is no longer needed.
	 */
	/* Create variable for x-axis in our workspace */
	T = mxCreateDoubleMatrix(1, BUF_SIZE, mxREAL);
	memcpy((void *)mxGetPr(T), (void *)time, sizeof(time));
	/*
	 * Place the variable T into the MATLAB workspace
	 */
	engPutVariable(ep, "T", T);

	/* Create variable for y-axis in our workspace */
	Ydata = mxCreateDoubleMatrix(1, BUF_SIZE, mxREAL);

	/*  Add new curves to MATLAB plots and retain previous curves  */
	    engEvalString(ep, "hold");

    /* Plot title and axis labels */
	engEvalString(ep, "title('Plot of Data Read From DSK');");
	engEvalString(ep, "xlabel('Data Sample Index');");
	engEvalString(ep, "ylabel('Data From DSK');");


    // initialize COM
     ::CoInitialize( NULL );

    // Instantiate the RTDX COM object
    // IRtdxExp interface
    hr = rtdx.CreateInstance( __uuidof(RTDXINTLib::RtdxExp) );
    cout.setf( ios::showbase );
    if ( FAILED(hr) ) {
       cerr << hex << hr << " - Error: Instantiation failed! \n";
        return -1;
	}

    // open a channel (ochan) for reading
     status = rtdx->Open( "ochan", "R" );
     if ( status != Success ) {
          cerr << hex << status \
               << " -  Error: Opening of a channel failed! \n";
                exit(-1);
     }

	/* Read and plot two data arrays from DSK  */
	 for(nn=0; nn < 2; nn++){

    // Read one array from the DSK
     for(data_count = 0; data_count < BUF_SIZE; data_count++) {
         // read a message
//          status = rtdx->ReadI4( &idata );  // To read integers

			status = rtdx->ReadF4(&fdata);

         // test status returned from ReadF4
          switch ( status ) {
                  case Success:
                          // display data
							cout << fdata << "\n";
						  // Save data in our array
							data_from_dsk[data_count] = fdata;
						        break;
                  case Failure:
                          cerr << hex << status \
                               << " - Error: ReadF4 returned failure! \n";
                         return -1;
                  case ENoDataAvailable:
                          cout << "\n\nNo Data is currently available!\n";
                          cout << "\n\nWould you like to continue reading [y or n]?\n";
                          char option;
                          cin >> option;
                          if ( (option == 'y') || (option == 'Y') )
                                  break;
                          else
                                  return -1;
                  case EEndOfLogFile:
                          cout << "\n\nEnd of log file reached.\n";
                          break;
                  default:
                          cerr << hex << status \
                               << " - Error: Unknown return code! \n";
                          return -1;
                }
        }  

	
    /*  Load the record read from the DSK into our workspace Ydata array  */ 
	memcpy((void *)mxGetPr(Ydata), (void *)data_from_dsk, sizeof(data_from_dsk));

	/*
	 * Place the variable Ydata into the MATLAB workspace
	 */
	engPutVariable(ep, "Ydata", Ydata);

	/*
	 * Plot the data read from the DSK
	 */
	engEvalString(ep, "plot(T,Ydata);");

	 }  /*  End of plotting nn loop */

	/*
	 * use fgetc() to make sure that we pause long enough to be
	 * able to see the plot
	 */
	cout << "Hit return to continue" << endl;
 	fgetc(stdin);

	/************************************************************************ 
	* This section of the program is just to test what happens when we try to
	*  read beyond the last word sent by the DSK.  It also gives the table
	*  of the numerical values of the "status" conditions for reads.                   
	**************************************************************************/
//   status = rtdx->ReadI4( &idata );  // To read integers

	status = rtdx->ReadF4( &fdata);
	cout << "Status of last word read = " << (unsigned int) status << "\n\n\n";

	cout << "Table of status Values \n";
	cout << "   " << Success << "           Status = Success \n";
	cout << "   " << (unsigned int) Failure << "  Status = Failure \n";
	cout << "   " << (unsigned int) ENoDataAvailable << "  Status = ENoDataAvailable\n";
	cout << "   " << (unsigned int) EEndOfLogFile << "  Status = EEndOfLogFile\n\n";
	/**********************************************************************************/

	/*
	 *  Free memory, close figure, and close engine.
	 */
	mxDestroyArray(T);
	mxDestroyArray(Ydata);
	engEvalString(ep, "close;");   /* "close" deletes the MATLAB figure */
	engClose(ep);

	// close the channel
    status = rtdx->Close();

    // release the IRtdxExp interface
    rtdx.Release();

    // uninitialize COM
    ::CoUninitialize();
	
	return 0;
}