//####################################################################
// S1L1.cpp - (Section 1, Lesson 1) SENDING AN INTEGER TO THE HOST
//            This is the RTDX Host Client for Section 1, Lesson1
//####################################################################

#import "C:\CCStudio_v3.1\cc\bin\rtdxint.dll"
#include <iostream>

using namespace std;   // Allows recognition of "cout",etc. without full
                       //  definition std::cout
using namespace RTDXINTLib;

int main()
{
        IRtdxExpPtr rtdx;       // Holds pointer to IRtdxExp interface
        long data;              // Holds data read from target application
        long status;            // Holds status of RTDX COM API calls
        HRESULT hr;             // Holds status of generic COM API calls

        // initialize COM
        ::CoInitialize( NULL );

        // Instantiate the RTDX COM object
        // IRtdxExp interface
        hr = rtdx.CreateInstance( __uuidof(RTDXINTLib::RtdxExp) );
        cout.setf( ios::showbase );

        if ( FAILED(hr) ) {
                cerr << hex << hr << " - Error: Instantiation failed! \n";
                return -1;
        }

        // open a channel (ochan) for reading
        status = rtdx->Open( "ochan", "R" );
        if ( status != Success ) {
                cerr << hex << status \
                     << " -  Error: Opening of a channel failed! \n";
                exit(-1);
        }

        // loop until we have read all of our messages
        do {
                // read a message
                status = rtdx->ReadI4( &data );

                // test status returned from ReadI4
                switch ( status ) {
                        case Success:
                                // display data
                                cout << data << "\n";
                                break;
                        case Failure:
                                cerr << hex << status \
                                     << " - Error: ReadI4 returned failure! \n";
                               return -1;
                        case ENoDataAvailable:
                                cout << "\n\nNo Data is currently available!\n";
                                cout << "\n\nWould you like to continue reading [y or n]?\n";
                                char option;
                                cin >> option;
                                if ( (option == 'y') || (option == 'Y') )
                                        break;
                                else
                                        return -1;
                        case EEndOfLogFile:
                                cout << "\n\nData Processing Complete!\n";
                                break;
                        default:
                                cerr << hex << status \
                                     << " - Error: Unknown return code! \n";
                                return -1;
                }
        } while ( status != EEndOfLogFile );

        // close the channel
        status = rtdx->Close();

        // release the IRtdxExp interface
        rtdx.Release();

        // uninitialize COM
        ::CoUninitialize();

        return 0;
}
