//####################################################################
// S1L1.cpp - (Section 1, Lesson 1) SENDING AN INTEGER TO THE HOST
//            This is the RTDX Host Client for Section 1, Lesson1
//
//  Project:  pc_rtdx_t2h
//####################################################################

/**********************************************************************
*  The function rtdx->ReadI4( ) expects it's argument to be a pointer to
*  an int. The union statement allows floats (32-bit words) sent by the DSK 
*  to be read as 32-bit ints by the PC host and used as floats.
**********************************************************************/

#import "C:\CCStudio_v3.1\cc\bin\rtdxint.dll"
#include <iostream> //Express 2008 and full 2008 academic versions don't add .h

using namespace std;   // Allows recognition of "cout",etc. without fully
                       //  qualified names std::cout
using namespace RTDXINTLib;

int main()
{
        IRtdxExpPtr rtdx;       // Holds pointer to IRtdxExp interface
//          long idata;            // Holds integer data read from target application
		  float fdata;          // Holds floating point data read from target

		long status;            // Holds status of RTDX COM API calls
        HRESULT hr;             // Holds status of generic COM API calls

        // initialize COM
        ::CoInitialize( NULL );

        // Instantiate the RTDX COM object
        // IRtdxExp interface
        hr = rtdx.CreateInstance( __uuidof(RTDXINTLib::RtdxExp) );
        cout.setf( ios::showbase );

        if ( FAILED(hr) ) {
                cerr << hex << hr << " - Error: Instantiation failed! \n";
                return -1;
        }

        // open a channel (ochan) for reading
        status = rtdx->Open( "ochan", "R" );
        if ( status != Success ) {
                cerr << hex << status \
                     << " -  Error: Opening of a channel failed! \n";
                exit(-1);
        }

        // loop until we have read all of our messages
        do {
                // read a message
//                status = rtdx->ReadI4( &idata );  //For reading integers
				status = rtdx->ReadF4(&fdata);

                // test status returned from ReadF4
                switch ( status ) {
                        case Success:
                                // display data
                                cout << fdata << "\n";
                                break;
                        case Failure:
                                cerr << hex << status \
                                     << " - Error: ReadF4 returned failure! \n";
                               return -1;
                        case ENoDataAvailable:
                                cout << "\n\nNo Data is currently available!\n";
                                cout << "\n\nWould you like to continue reading [y or n]?\n";
                                char option;
                                cin >> option;
                                if ( (option == 'y') || (option == 'Y') )
                                        break;
                                else
                                        return -1;
                        case EEndOfLogFile:
                                cout << "\n\nData Processing Complete!\n";
                                break;
                        default:
                                cerr << hex << status \
                                     << " - Error: Unknown return code! \n";
                                return -1;
                }
        } while ( status != EEndOfLogFile );

        // close the channel
        status = rtdx->Close();

        // release the IRtdxExp interface
        rtdx.Release();

        // uninitialize COM
        ::CoUninitialize();

        return 0;
}
