/*************************************************************************
* FILENAME: t2h_Test.c
* DATE    : December 30, 2007
*
* Target-To-Host Test:
*____________________________________________________________________
* - Sends 100 integers, one at a time via RTDX_write().
* - Uses ONE output channel.
*
* - Tests Data transmission from target to host at the User layer.
* - This is the module to be run on the TARGET.
*
*   Remember to enable RTDX in CCS by clicking on Tools -> RTDX ->
*    Configuration Control and then click on the little white square
*   to the left of "Enable RTDX."
*
*   The directory ...\c6713dskAnswers\RTDX_Test\pc_rtdx_express contains a 
*   Visual C++ 2008 Express project for building a host program for
*   reading the numbers sent by the DSK to the PC by RTDX. The program
*   ...\pc_rtdx\debug\pc_rtdx.exe is a prebuilt exe you can run on the
*   PC.  The C++ source file is s1l1.cpp. (Note: You can download 
*   C++ Express free from Microsoft. Google "C++ Express" to find out
*   where to get it.)
*
*   The directory ...\c6713dskAnswers\RTDX_Test\pc_rtdx_test contains a Visual
*   C++ 2008 project for building a host program for reading the numbers sent
*   by the DSK to the PC by RTDX.
*
*   The interupt vectors and functions are defined in the header 
*   DSKintr.h and files intvecs.asm and DSKint.c. The object modules
*   intvecs.obj and DSKint.obj have been added to the library
*   dsk6713bsl32.lib. If you wish to modify intvecs.asm and DSKint.c, simply
*   add these source files to your project and re-compile. You can put 
*   the resulting obj's into the library using ar6x.exe.
*
*   You should use the linker command file dsk6713_RTDX.cmd
*
*   The TI RTDX tutorial shows the argument of RTDX_write( ) as a pointer
*   to an unsigned 32-bit integer. As this example shows, it can also be a float
*   which also occupies a 32-bit word.  
*************************************************************************/
#include <stdio.h>              /* fprintf(), puts()                    */
#include <stdlib.h>             /* abort()                              */
#include <rtdx.h>               /* RTDX                                 */
#include <dsk6713.h>
#include "DSKintr.h"

/* Declare and initialize an output channel called "ochan"              */
RTDX_CreateOutputChannel(ochan);

#define NUMBER_MESSAGES 100

void main( void )
{
    float fdata;   
    DSK6713_init();
    intr_reset();

    /* Turn on interrupts                                               */
    INTR_ENABLE(CPU_INT_NMI);
    INTR_ENABLE(CPU_INT_RSV2); /* RTDX uses RESV2 interrupt             */
    INTR_GLOBAL_ENABLE();
	    
    /* Enable the output channel, "ochan"                               */
    RTDX_enableOutput(&ochan);
    
    printf("Sending %d Messages to Host...\n", NUMBER_MESSAGES);
    for (fdata = 0.5; fdata < NUMBER_MESSAGES; fdata++ ) {
        /* Send the data to the host                                     */
		if ( !RTDX_write( &ochan, &fdata, sizeof(fdata) ) ) {
            fprintf(stderr, "\nError: RTDX_write() failed!\n");
            abort();
        }
        
        /* Wait for Target-to-Host transfer to complete                 */
        while ( RTDX_writing != NULL ) {
        }
        
        /* Display what was sent in the stdout window                   */
    fprintf(stdout, "Value %f was sent to the host\n", fdata);
    }
    
    /* Disable the output channel, "ochan"                              */
    RTDX_disableOutput(&ochan);
    
    puts("\nTest Completed!"); 
}
